from cpl_core.database.context import DatabaseContextABC
from cpl_discord.service import DiscordBotServiceABC

from bot_core.abc.client_utils_abc import ClientUtilsABC
from bot_data.abc.auto_role_repository_abc import AutoRoleRepositoryABC
from bot_data.abc.server_repository_abc import ServerRepositoryABC
from bot_data.model.auto_role_rule import AutoRoleRule
from bot_data.model.user_role_enum import UserRoleEnum
from bot_graphql.abc.query_abc import QueryABC


class AutoRoleRuleMutation(QueryABC):
    def __init__(
        self,
        bot: DiscordBotServiceABC,
        servers: ServerRepositoryABC,
        auto_roles: AutoRoleRepositoryABC,
        db: DatabaseContextABC,
        client_utils: ClientUtilsABC,
    ):
        QueryABC.__init__(self, "AutoRoleRuleMutation")

        self._bot = bot
        self._servers = servers
        self._auto_roles = auto_roles
        self._db = db
        self._client_utils = client_utils

        self.set_field("createAutoRoleRule", self.resolve_create_auto_role_rule)
        self.set_field("updateAutoRoleRule", self.resolve_update_auto_role_rule)
        self.set_field("deleteAutoRoleRule", self.resolve_delete_auto_role_rule)

    def resolve_create_auto_role_rule(self, *_, input: dict):
        auto_role_rule = AutoRoleRule(
            self._auto_roles.get_auto_role_by_id(input["autoRoleId"]), input["emojiName"], input["roleId"]
        )
        self._can_user_mutate_data(auto_role_rule.auto_role.server, UserRoleEnum.moderator)

        self._auto_roles.add_auto_role_rule(auto_role_rule)
        self._db.save_changes()

        def get_new(x: AutoRoleRule):
            return (
                x.auto_role.id == int(input["autoRoleId"])
                and x.emoji_name == input["emojiName"]
                and x.role_id == int(input["roleId"])
            )

        self._bot.loop.create_task(
            self._client_utils.react_to_message_by_auto_role_rule(
                auto_role_rule.auto_role.discord_channel_id,
                auto_role_rule.auto_role.discord_message_id,
                auto_role_rule,
                self._bot.get_guild(auto_role_rule.auto_role.server.discord_id),
            )
        )
        return self._auto_roles.get_auto_role_rules_by_auto_role_id(auto_role_rule.auto_role.id).where(get_new).last()

    def resolve_update_auto_role_rule(self, *_, input: dict):
        auto_role_rule = self._auto_roles.get_auto_role_rule_by_id(input["id"])
        self._can_user_mutate_data(auto_role_rule.auto_role.server, UserRoleEnum.moderator)

        auto_role_rule.emoji_name = input["emojiName"] if "emojiName" in input else auto_role_rule.emoji_name
        auto_role_rule.role_id = input["roleId"] if "roleId" in input else auto_role_rule.role_id

        self._auto_roles.update_auto_role_rule(auto_role_rule)
        self._db.save_changes()

        auto_role_rule = self._auto_roles.get_auto_role_rule_by_id(input["id"])
        self._bot.loop.create_task(
            self._client_utils.react_to_message_by_auto_role_rule(
                auto_role_rule.auto_role.discord_channel_id,
                auto_role_rule.auto_role.discord_message_id,
                auto_role_rule,
                self._bot.get_guild(auto_role_rule.auto_role.server.discord_id),
            )
        )
        return auto_role_rule

    def resolve_delete_auto_role_rule(self, *_, id: int):
        auto_role_rule = self._auto_roles.get_auto_role_rule_by_id(id)
        self._can_user_mutate_data(auto_role_rule.auto_role.server, UserRoleEnum.moderator)

        self._auto_roles.delete_auto_role_rule(auto_role_rule)
        self._db.save_changes()
        return auto_role_rule
