import discord
from cpl_discord.command import DiscordCommandABC
from cpl_discord.service import DiscordBotServiceABC
from cpl_translation import TranslatePipe
from discord.ext import commands
from discord.ext.commands import Context

from bot_core.abc.client_utils_abc import ClientUtilsABC
from bot_core.abc.message_service_abc import MessageServiceABC
from bot_core.helper.command_checks import CommandChecks
from bot_core.logging.command_logger import CommandLogger
from bot_data.abc.server_repository_abc import ServerRepositoryABC
from bot_data.model.technician_config import TechnicianConfig
from modules.permission.abc.permission_service_abc import PermissionServiceABC


class PingCommand(DiscordCommandABC):
    def __init__(
        self,
        logger: CommandLogger,
        message_service: MessageServiceABC,
        bot: DiscordBotServiceABC,
        client_utils: ClientUtilsABC,
        translate: TranslatePipe,
        permissions: PermissionServiceABC,
        servers: ServerRepositoryABC,
        settings: TechnicianConfig,
    ):
        DiscordCommandABC.__init__(self)

        self._logger = logger
        self._message_service = message_service
        self._bot = bot
        self._client_utils = client_utils
        self._t = translate
        self._permissions = permissions
        self._servers = servers
        self._settings = settings

        self._logger.trace(__name__, f"Loaded command service: {type(self).__name__}")

    @staticmethod
    def _get_ping(url: str) -> float:
        from icmplib import ping

        ping_result = ping(url, count=4, interval=0.2, privileged=False)
        return ping_result.avg_rtt

    @commands.hybrid_command()
    @commands.guild_only()
    @CommandChecks.check_is_ready()
    async def ping(self, ctx: Context):
        self._logger.debug(__name__, f"Received command ping {ctx}")
        if self._permissions.is_member_technician(ctx.author):
            embed = discord.Embed(
                title=self._t.transform("modules.base.info.title"),
                description=self._t.transform("modules.base.info.description"),
                color=int("ef9d0d", 16),
            )
            for server in self._settings.ping_urls:
                embed.add_field(name=server, value=f"{self._get_ping(server)} ms", inline=False)
            await self._message_service.send_ctx_msg(ctx, embed)
        else:
            await self._message_service.send_ctx_msg(ctx, self._t.transform("modules.base.pong"))
        self._logger.trace(__name__, f"Finished ping command")
