export class Mutations {
  static updateUser = `
    mutation updateUser($id: ID, $xp: Int, $levelId: ID) {
      user {
        updateUser(input: { id: $id, xp: $xp, levelId: $levelId }) {
          id
          name
          xp
          level {
            id
            name
          }
        }
      }
    }
  `;

  static createAutoRole = `
    mutation createAutoRole($serverId: ID, $channelId: String, $messageId: String) {
      autoRole {
        createAutoRole(input: { serverId: $serverId, channelId: $channelId, messageId: $messageId }) {
          id
          channelId
          channelName
          messageId
        }
      }
    }
  `;

  static deleteAutoRole = `
    mutation deleteAutoRole($id: ID) {
      autoRole {
        deleteAutoRole(id: $id) {
          id
          channelId
          channelName
          messageId
        }
      }
    }
  `;

  static createAutoRoleRule = `
    mutation createAutoRoleRule($autoRoleId: ID, $emojiName: String, $roleId: String) {
      autoRoleRule {
        createAutoRoleRule(input: { autoRoleId: $autoRoleId, emojiName: $emojiName, roleId: $roleId }) {
          id
          emojiName
          roleId
          roleName
        }
      }
    }
  `;

  static updateAutoRoleRule = `
    mutation updateAutoRoleRule($id: ID, $emojiName: String, $roleId: String) {
      autoRoleRule {
        updateAutoRoleRule(input: { id: $id, emojiName: $emojiName, roleId: $roleId }) {
          id
          emojiName
          roleId
          roleName
        }
      }
    }
  `;

  static deleteAutoRoleRule = `
    mutation deleteAutoRoleRule($id: ID) {
      autoRoleRule {
        deleteAutoRoleRule(id: $id) {
          id
          emojiName
          roleId
          roleName
        }
      }
    }
  `;

  static createLevel = `
    mutation createLevel($name: String, $color: String, $minXp: Int, $permissions: String, $serverId: ID) {
      level {
        createLevel(input: { name: $name, color: $color, minXp: $minXp, permissions: $permissions, serverId: $serverId}) {
          id
          name
          color
          minXp
          permissions
          server {
            id
          }
        }
      }
    }
  `;

  static updateLevel = `
    mutation updateLevel($id: ID, $name: String, $color: String, $minXp: Int, $permissions: String) {
      level {
        updateLevel(input: { id: $id, name: $name, color: $color, minXp: $minXp, permissions: $permissions }) {
          id
          name
          color
          minXp
          permissions
        }
      }
    }
  `;

  static deleteLevel = `
    mutation deleteLevel($id: ID) {
      level {
        deleteLevel(id: $id) {
          id
          name
        }
      }
    }
  `;

  static createAchievement = `
    mutation createAchievement($name: String, $description: String, $attribute: String, $operator: String, $value: String, $serverId: ID) {
      achievement {
        createAchievement(input: { name: $name, description: $description, attribute: $attribute, operator: $operator, value: $value, serverId: $serverId}) {
          id
          name
          description
          attribute
          operator
          value
          server {
            id
          }
        }
      }
    }
  `;

  static updateAchievement = `
    mutation updateAchievement($id: ID, $name: String, $description: String, $attribute: String, $operator: String, $value: String) {
      achievement {
        updateAchievement(input: { id: $id, name: $name, description: $description, attribute: $attribute, operator: $operator, value: $value}) {
          id
          name
          description
          attribute
          operator
          value
        }
      }
    }
  `;

  static deleteAchievement = `
    mutation deleteAchievement($id: ID) {
      achievement {
        deleteAchievement(id: $id) {
          id
          name
        }
      }
    }
  `;

  static createShortRoleName = `
    mutation createShortRoleName($shortName: String, $roleId: String, $position: String, $serverId: ID) {
      shortRoleName {
        createShortRoleName(input: { shortName: $shortName, roleId: $roleId, position: $position, serverId: $serverId}) {
          id
          shortName
          roleId
          roleName
          position
          server {
            id
          }
        }
      }
    }
  `;

  static updateShortRoleName = `
    mutation updateShortRoleName($id: ID, $shortName: String, $roleId: String, $position: String, $serverId: ID) {
      shortRoleName {
        updateShortRoleName(input: { id: $id, shortName: $shortName, roleId: $roleId, position: $position, serverId: $serverId }) {
          id
          shortName
          roleId
          roleName
          position
        }
      }
    }
  `;

  static deleteShortRoleName = `
    mutation deleteShortRoleName($id: ID) {
      shortRoleName {
        deleteShortRoleName(id: $id) {
          id
          shortName
        }
      }
    }
  `;

  static updateTechnicianConfig = `
    mutation updateTechnicianConfig($id: ID, $helpCommandReferenceUrl: String, $waitForRestart: Int, $waitForShutdown: Int, $cacheMaxMessages: Int, $featureFlags: [FeatureFlagInput], $pingURLs: [String], $technicianIds: [String]) {
      technicianConfig {
        updateTechnicianConfig(input: {
            id: $id,
            helpCommandReferenceUrl: $helpCommandReferenceUrl,
            waitForRestart: $waitForRestart,
            waitForShutdown: $waitForShutdown,
            cacheMaxMessages: $cacheMaxMessages,
            featureFlags: $featureFlags,
            pingURLs: $pingURLs,
            technicianIds: $technicianIds
          }) {
          id
          helpCommandReferenceUrl
          waitForRestart
          waitForShutdown
          cacheMaxMessages
          featureFlags {
            key
            value
          }
          pingURLs
          technicianIds
        }
      }
    }
  `;

  static updateServerConfig = `
    mutation updateServerConfig(
      $id: ID,
      $messageDeleteTimer: Int,
      $notificationChatId: String,
      $maxVoiceStateHours: Int,
      $xpPerMessage: Int,
      $xpPerReaction: Int,
      $maxMessageXpPerHour: Int,
      $xpPerOntimeHour: Int,
      $xpPerEventParticipation: Int,
      $xpPerAchievement: Int,
      $afkCommandChannelId: String,
      $helpVoiceChannelId: String,
      $teamChannelId: String,
      $loginMessageChannelId: String,
      $defaultRoleId: String,
      $shortRoleNameOnlySetHighestRole: Boolean
      $featureFlags: [FeatureFlagInput],
      $afkChannelIds: [String],
      $moderatorRoleIds: [String],
      $adminRoleIds: [String]
    ) {
      serverConfig {
        updateServerConfig(input: {
            id: $id,
            messageDeleteTimer: $messageDeleteTimer,
            notificationChatId: $notificationChatId,
            maxVoiceStateHours: $maxVoiceStateHours,
            xpPerMessage: $xpPerMessage,
            xpPerReaction: $xpPerReaction,
            maxMessageXpPerHour: $maxMessageXpPerHour,
            xpPerOntimeHour: $xpPerOntimeHour,
            xpPerEventParticipation: $xpPerEventParticipation,
            xpPerAchievement: $xpPerAchievement,
            afkCommandChannelId: $afkCommandChannelId,
            helpVoiceChannelId: $helpVoiceChannelId,
            teamChannelId: $teamChannelId,
            loginMessageChannelId: $loginMessageChannelId,
            defaultRoleId: $defaultRoleId,
            shortRoleNameOnlySetHighestRole: $shortRoleNameOnlySetHighestRole,
            featureFlags: $featureFlags,
            afkChannelIds: $afkChannelIds,
            moderatorRoleIds: $moderatorRoleIds,
            adminRoleIds: $adminRoleIds
          }) {
          id
          messageDeleteTimer
          notificationChatId
          maxVoiceStateHours
          xpPerMessage
          xpPerReaction
          maxMessageXpPerHour
          xpPerOntimeHour
          xpPerEventParticipation
          xpPerAchievement
          afkCommandChannelId
          helpVoiceChannelId
          teamChannelId
          loginMessageChannelId
          defaultRoleId
          shortRoleNameOnlySetHighestRole
          featureFlags {
            key
            value
          }
          afkChannelIds
          moderatorRoleIds
          adminRoleIds

          server {
            id
          }
        }
      }
    }
  `;
}
